@@ -5,12 +5,13 @@ class xcylobj(object):
 	"""
 	the new excel object
 	"""
-	def __init__(self, filename: str = "TEMP_VALUE", useIndex: bool = False):
+	def __init__(self, filename: str = "TEMP_VALUE", useIndex: bool = False, useSheets: bool = True):
 		if not filename.endswith(".xlsx"):
 			filename += ".xlsx"
 		self.filename = filename
 		self.cur_data_sets = {}
 		self.useIndex = useIndex
+		self.useSheetNames = useSheets
 
 		if os.path.exists(self.filename):
 			print("Loading existing file")
@@ -49,10 +50,11 @@ class xcylobj(object):
 					dyct[key] = [dyct[key]]
 				return pd.DataFrame.from_dict(dyct)
 
-			self['sheet_names'] = pd.concat(list(map(
-				dyct_frame,
-				sheet_names
-			)), ignore_index=True)
+			if self.useSheetNames:
+				self['sheet_names'] = pd.concat(list(map(
+					dyct_frame,
+					sheet_names
+				)), ignore_index=True)
 
 			with pd.ExcelWriter(self.filename, engine="xlsxwriter") as writer:
 				for key, value in self.cur_data_sets.items():
